function gtConvertRawImages2Blobs(acq_name, first, last)
    if (~exist('first', 'var'))
        first = 1;
    end
    difblob_num = mym(['select count(*) from ' acq_name 'difblob']);
    if (~exist('last', 'var'))
        last = difblob_num;
    end

    info = edf_info(fullfile('1_preprocessing', 'full', 'full0000.edf'));

    stats = GtTasksStatistics();
    stats.add_task('load_blob', 'Time to load from DB');
    stats.add_task('save_blob', 'Time to save to HDF5');
    stats.add_task('convert_blob', 'Time for converting from DB to HDF5')

    table_difspot = sprintf('%sdifspot', acq_name);

    fprintf('Progress: ')
    c = tic();
    for ii = first:last
        num_chars = fprintf('%06d/%06d (%s)', ii, (last - first + 1), ...
            stats.get_formatted_total('convert_blob'));
        stats.tic('convert_blob')
        stats.tic('load_blob')
        [blob, bb] = get_blob(table_difspot, ii, info);
        blob(blob < 0) = 0;
        stats.toc('load_blob')

        stats.tic('save_blob')
        gtWriteBlobToHDF5('2_difblob', ii, blob, bb);
        stats.toc('save_blob')
        stats.toc('convert_blob')

        fprintf(repmat('\b', [1 num_chars]))
    end
    fprintf('%06d Done in %f seconds.\n', (last - first + 1), toc(c));
    stats.printStats()
end

function [blob, bb] = get_blob(table_difspot, difspotID, info)

    colnames(1, :) = { 'Integral', 'StartImage', 'EndImage' ...
        'BoundingBoxXorigin', 'BoundingBoxYorigin', ...
        'BoundingBoxXsize', 'BoundingBoxYsize',  };
    colnames(2, :) = {', '};

    query = sprintf('SELECT %s FROM %s WHERE difspotID = %d', ...
        [colnames{1:end-1}], table_difspot, difspotID );

    [~, bb(3), bb(6), bb(1), bb(2), bb(4), bb(5)] = mym(query);
    bb(6) = bb(6) - bb(3) + 1;

    for s_ii = bb(6):-1:1
        image_num = bb(3) - 1 + s_ii;
        filename = fullfile('1_preprocessing', 'full', sprintf('full%04d.edf', image_num));
        GT_bb = [bb(1), bb(2), bb(4), bb(5)];
        blob(:, :, s_ii) = edf_read(filename, GT_bb, false, info);
    end
end
