function vol = gtAstraReconstructGrain(grainID, phaseID, parameters, sample)
% GTASTRARECONSTRUCTGRAIN  3D ART (ASTRA) reconstruction on a GPU machine
%     gtAstraReconstructGrain(grainID, phaseID, [parameters])
%     -------------------------------------------------------
%     Needs to be submitted on a GPU machine
%     (varargin for OAR_make: {'gpu',true} or 'oarsub -q gpu ...')
%
%     Reads 4_grains/sample.mat                 : phases{phaseID}.grains{grainID}.selectedDiffspots
%     Reads 4_grains/phase_##/grain_****.mat    : proj,[selected]
%     Modifies 4_grains/phase_##/grain_****.mat : proj.stack, proj.geom
%     Appends 4_grains/phase_##/grain_****.mat  : vol
%
%     Version 002 29-05-2012 by LNervo
%       Commenting and formatting
%


if ~exist('parameters','var') || isempty(parameters)
    load('parameters.mat');
end

if ~exist('sample','var')
    samplefile = fullfile(parameters.acq.dir, '4_grains', 'sample.mat');
    sample = GtSample.loadFromFile(samplefile);
end

selected = logical(sample.phases{phaseID}.grains{grainID}.selectedDiffspots);

grainfile = fullfile(parameters.acq.dir, '4_grains', ...
                     sprintf('phase_%02d', phaseID), ...
                     sprintf('grain_%04d.mat',grainID));

                 % in case sample.mat is not yet existing - read selected from
% grain_xxxx.mat
proj = [];
if isempty(selected)
   load(grainfile, 'proj', 'selected');
else
   load(grainfile, 'proj');
end

proj.stack = proj.stack(:, selected, :);
proj.geom  = proj.geom(selected, :);
if isfield(parameters.labgeo, 'sourcepoint') && ~isempty(parameters.labgeo.sourcepoint)
    vol = gtAstra3DCone([], [], [], proj);
else
    vol = gtAstra3D([], [], [], proj);
end

save(grainfile,'-append','vol')

end % end of function
