function gtSetupForwardSimulation()
% GTSETUPFORWARDSIMULATION  Simple helper function to run gtForwardSimulate_v2
%     gtSetupForwardSimulation()
%     --------------------------


parameters = [];
load('parameters.mat');

% Let's check every field is in, and in case let's update it!
parameters = gtCheckParameters(parameters, 'fsim', {'default'}, false, true);
save(fullfile(parameters.acq.dir, 'parameters.mat'),'parameters');

gtDBConnect();

check=inputwdefault('Do you want to recompile the function ''gtForwardSimulate_v2''? [y/n]','n');
if strcmpi(check,'y')
    gtExternalCompileFunctions('gtForwardSimulate_v2');
end

nof_phases = length(parameters.cryst);

if nof_phases > 1
    phaseID = inputwdefaultnumeric('Enter phaseID', num2str(1));
else
    phaseID = 1;
end

phaseID_str = sprintf('%02d',phaseID);

disp(['Setting up Forward Simulation for phase ' phaseID_str ' ' parameters.cryst(phaseID).name]);

% get the latest version of indexter output
ngrains = zeros([1 nof_phases]);
for ii = 1 : nof_phases
    grain = [];
    index_filename = fullfile(parameters.acq.dir, '4_grains', sprintf('phase_%02d',ii), 'index.mat');
    load(index_filename, 'grain');
    % how many grains in this dataset?
    ngrains(ii) = length(grain);
end

% reset grain_####.mat
for ii = 1 : nof_phases
    check = inputwdefault('Do you want to delete the previous grain_####.mat files? [y/n]','y');
    if strcmpi(check,'y')
        delete( fullfile(parameters.acq.dir, '4_grains', sprintf('phase_%02d',ii), 'grain_*.mat') );
    else
        disp('You may have problems in the future with the grain_###.mat files.');
    end
end

% create / reset sample.mat
sample_filename = fullfile(parameters.acq.dir, '4_grains', 'sample.mat');
if ( exist(sample_filename, 'file') && nof_phases > 1 )
    sample = GtSample.loadFromFile(sample_filename);     % do not create from scratch - we want to keep information related to other phases
else
    sample = GtSample(nof_phases);
    sample.fileTable = [parameters.acq.name '_filetable'];
    for ii = 1 : nof_phases
        phase = GtPhase(parameters.cryst(ii).name, ngrains(ii));
        sample.phases{ii} = phase;
    end
    save(sample_filename, 'sample');
end

disp(['Reset phase number ' phaseID_str ' in the sample.mat:']);
disp(['  Phase name : ' parameters.cryst(phaseID).name]);
disp(['  Nof_grains : ' num2str(ngrains(phaseID))]);

% create / reset spot2grain.mat
filename = fullfile(parameters.acq.dir, '4_grains', 'spot2grain.mat');
difspot_num  = mym(['select count(*) from ' parameters.acq.name 'difspot']);

if ( exist(filename, 'file') && nof_phases > 1 )
    check = inputwdefault('Do you want to reset spot2grain? [y/n]', 'n');
    if strcmpi(check,'y')
        spot2grain  = cell(difspot_num, 1); % cell array linking difspots with grainids
        spot2phase  = cell(difspot_num, 1);
        save(filename,'spot2grain','spot2phase');
    end
else
    spot2grain  = cell(difspot_num, 1); % cell array linking difspots with grainids
    spot2phase  = cell(difspot_num, 1);
    save(filename,'spot2grain','spot2phase');
end

% get reconstruction parameters
check = inputwdefault('Use existing parameters for forward simulation? [y/n]', 'y');
if ~strcmpi(check,'y')
    list = build_list_v2();
    parameters.fsim = gtModifyStructure(parameters.fsim, list.fsim, 1, 'Forward simulation parameters:');
    save(fullfile(parameters.acq.dir, 'parameters.mat'),'parameters');
end

% launch forward simulation process to OAR - split to two jobs
check = inputwdefault('Launch Forward Simulation with OAR (o) or here on the command line (c)? [o/c]', 'o');
if strcmpi(check,'o')
    disp('Launching several separate OAR jobs');

    oar.njobs    = min(ceil(ngrains(phaseID)/20), 30); % max 30 jobs
    oar.walltime = ngrains(phaseID) / oar.njobs * 5 * 60;  % allow 5 minutes per grain % in seconds
    oar.mem      = 2000; %Mb
     
    % oar parameters are defined in build_list_v2
    list = build_list_v2();
    OAR_parameters = gtModifyStructure(oar, list.oar, 1, 'OAR parameters:');

    OARtmp = ceil(OAR_parameters.walltime / 60); % minutes
    OARm   = mod(OARtmp, 60); % minutes
    OARh   = (OARtmp - OARm) / 60; % hours

    OAR_parameters.walltime = sprintf('%02d:%02d:00', OARh, OARm);

    disp('Using OAR parameters:')
    disp(OAR_parameters)
    disp(['Using ' num2str(OAR_parameters.njobs) ' OAR jobs']);

    pause(0.5);
    
    if isfield(parameters.labgeo, 'sourcepoint') && ~isempty(parameters.labgeo.sourcepoint)
        OAR_make('gtForwardSimulatePoly', 1, ngrains(phaseID), OAR_parameters.njobs, ...
            [parameters.acq.dir ' ' phaseID_str], true, ...
            'walltime', OAR_parameters.walltime, 'mem', OAR_parameters.mem);
    else
        OAR_make('gtForwardSimulate_v2', 1, ngrains(phaseID), OAR_parameters.njobs, ...
            [parameters.acq.dir ' ' phaseID_str], true, ...
            'walltime', OAR_parameters.walltime, 'mem', OAR_parameters.mem);
    end
else
    
    disp('Launching forward simulation...')
    disp(' ')
    
    if isfield(parameters.labgeo, 'sourcepoint') && ~isempty(parameters.labgeo.sourcepoint)
        gtForwardSimulatePoly(1, ngrains(phaseID), parameters.acq.dir, phaseID);
    else
        gtForwardSimulate_v2(1, ngrains(phaseID), parameters.acq.dir, phaseID);
    end

end

end % end of function
