function dlab = gtFedPredictDiffVecMultiple(pllab, beamdir)
% GTFEDPREDICTDIFFVECMULTIPLE Diffraction vectors from plane normals and 
% beam directions in the Lab reference. Vectorised for speed.
%
% dlab = gtFedPredictDiffVecMultiple(pllab, beamdir)
%
% --------------------------------------------------------------
% 
% Returns the diffraction vectors for a set of plane normals and beam 
% directions. All given in the Lab reference (i.e. turned into the omega 
% rotational position). Output 'dlab' is NOT normalised!
%
% INPUT
%   pllab   - normalised plane normals (3xn)
%   beamdir - normalised beam direction(s) (3x1) or (3xn)
%
% OUTPUT
%   dlab    - diffraction vectors (diffracted beam directions);
%             NOT normalised! (3xn)

 
if (size(beamdir, 1) == 3) && (size(beamdir, 2) == 1)
    dotpro = 2 * beamdir' * pllab;
    dlab   = beamdir(:, ones(1, size(pllab, 2))) - dotpro([1 1 1], :) .* pllab;
else
    dotpro = 2 * sum(beamdir .* pllab, 1);
    dlab   = beamdir - dotpro([1 1 1], :) .* pllab;
end

% % Another way could be using sin(theta), but it's inefficient unless 
% % the sign is known in advance. 
% if isempty(sinth)
% ...   
% else
%     if size(beamdir,1)==3 && size(beamdir,2)==1
%         % Need to consider the plane normal pointing opposite to the beam:
%         pllabsign = -sign(beamdir'*pllab);
%         pllab     = pllabsign([1 1 1],:).*pllab;
%         
%         % Diffraction vector:
%         dlab = 2*sinth([1 1 1],:).*pllab + beamdir(:,ones(1,size(pllab,2))) ;
%         
%     else
%         % Need to consider the plane normal pointing opposite to the beam:
%         pllabsign = -sign(sum(beamdir.*pllab,1));
%         pllab     = pllabsign([1 1 1],:).*pllab;
%         
%         % Diffraction vector:
%         dlab = 2*sinth([1 1 1],:).*pllab + beamdir ;
%     end
% end


end % end of function