/*
 * gtSoftThreshold.cpp
 *
 *  Created on: Jul 17, 2012
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#include "internal_array_defs.h"

#include "mex.h"

void mexFunction( int nlhs, mxArray * plhs[], int nrhs, const mxArray * prhs[] )
{
  if (!(nrhs == 3 || nrhs == 2)) {
    mexErrMsgIdAndTxt("C_FUN:gtSoftThreshold:wrong_argument",
        "Not enough arguments! You need to provide an array, a threshold and "
        "optionally a flag that tells if making a copy is necessary (default: true)");
  }
  if (!(mxIsDouble(prhs[1]) || mxIsSingle(prhs[1]))) {
    mexErrMsgIdAndTxt("C_FUN:gtSoftThreshold:wrong_argument",
        "The second parameter should be a double containing the threshold");
  }

  mxLogical copy = true;
  if (nrhs == 3) {
    if (!mxIsLogicalScalar(prhs[2])) {
      mexErrMsgIdAndTxt("C_FUN:gtSoftThreshold:wrong_argument",
          "The third parameter should be a logical");
    } else {
      copy = mxIsLogicalScalarTrue(prhs[2]);
    }
  }

  if (mxIsDouble(prhs[0])) {
    double threshold = 0;
    if (mxGetNumberOfElements(prhs[1]) != 0) {
      if (mxIsDouble(prhs[1])) {
        threshold = *mxGetPr(prhs[1]);
      } else {
        threshold = *(const float *)mxGetData(prhs[1]);
      }
    }
    soft_threshold<mwSize, double> thr(threshold);

    const mwSize numElems = mxGetNumberOfElements(prhs[0]);
    if (copy) {
      const mwSize numDims = mxGetNumberOfDimensions(prhs[0]);
      const mwSize * dims = mxGetDimensions(prhs[0]);
      plhs[0] = mxCreateNumericArray(numDims, dims, mxDOUBLE_CLASS, mxREAL);

      thr(mxGetPr(plhs[0]), mxGetPr(prhs[0]), numElems);
    } else {
      plhs[0] = (mxArray *) prhs[0];

      thr(mxGetPr(plhs[0]), numElems);
    }
  } else if (mxIsSingle(prhs[0])) {
    float threshold = 0;
    if (mxGetNumberOfElements(prhs[1]) != 0) {
      if (mxIsDouble(prhs[1])) {
        threshold = *mxGetPr(prhs[1]);
      } else {
        threshold = *(const float *)mxGetData(prhs[1]);
      }
    }
    soft_threshold<mwSize, float> thr(threshold);

    const mwSize numElems = mxGetNumberOfElements(prhs[0]);
    if (copy) {
      const mwSize numDims = mxGetNumberOfDimensions(prhs[0]);
      const mwSize * dims = mxGetDimensions(prhs[0]);
      plhs[0] = mxCreateNumericArray(numDims, dims, mxSINGLE_CLASS, mxREAL);

      thr((float *)mxGetData(plhs[0]), (const float *)mxGetData(prhs[0]), numElems);
    } else {
      plhs[0] = (mxArray *) prhs[0];

      thr((float *)mxGetData(plhs[0]), numElems);
    }
  }
}




