/*
 * internal_cell_sum_scaled.cpp
 *
 *  Created on: Jul 11, 2012
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#include "internal_cell_defs.h"

const char * errorID = "C_FUN:cell_sum_scaled_copy:wrong_argument";

void mexFunction( int nlhs, mxArray * plhs[], int nrhs, const mxArray * prhs[] )
{
  if (nrhs != 3) {
    mexErrMsgIdAndTxt(errorID,
        "Not enough arguments! you need to provide two cell arrays and the scale as a double");
  }
  if (!mxIsCell(prhs[0])) {
    mexErrMsgIdAndTxt(errorID,
        "The first argument should be a Cell array");
  }
  if (!mxIsCell(prhs[1])) {
    mexErrMsgIdAndTxt(errorID,
        "The second argument should be a Cell array");
  }
  if (!mxIsDouble(prhs[2])) {
    mexErrMsgIdAndTxt(errorID,
        "The third argument should be a double");
  }
  const mwSize numElems1 = mxGetNumberOfElements(prhs[0]);
  const mwSize numElems2 = mxGetNumberOfElements(prhs[1]);

  if (numElems1 != numElems2) {
    mexErrMsgIdAndTxt(errorID,
        "The Cell arrays should have the same size");
  }

  const mxClassID firstClass = getMxClassOfCell(prhs[0]);
  if (firstClass != getMxClassOfCell(prhs[1])) {
    mexErrMsgIdAndTxt(errorID,
        "The arguments need to be Cell arrays of coherent floating point types");
  }

  double scale;
  if (mxIsDouble(prhs[2])) {
    scale = *mxGetPr(prhs[2]);
  } else if (mxIsSingle(prhs[2])) {
    scale = *(float *)mxGetData(prhs[2]);
  } else {
    mexErrMsgIdAndTxt(errorID,
        "The scale needs to be of a floating point type");
  }

  switch (firstClass) {
    case mxDOUBLE_CLASS: {
      inner_sub_scale<double> func(scale);
#ifdef __SSE2__
      cell_iteration_copy_sse<double>(plhs[0], prhs[0], prhs[1], func);
#else
      cell_iteration_copy<double>(plhs[0], prhs[0], prhs[1], func);
#endif
      break;
    }
    case mxSINGLE_CLASS: {
      inner_sub_scale<float> func(scale);
#ifdef __SSE2__
      cell_iteration_copy_sse<float>(plhs[0], prhs[0], prhs[1], func);
#else
      cell_iteration_copy<float>(plhs[0], prhs[0], prhs[1], func);
#endif
      break;
    }
    case mxUNKNOWN_CLASS: {
      mexErrMsgIdAndTxt(errorID,
          "The argument needs to be a non empty Cell array of coherent floating point types");
    }
    default: {
      mexErrMsgIdAndTxt(errorID,
          "The argument needs to be a Cell array of floating point numbers");
    }
  }
}


