/*
 * internal_cell_sum.cpp
 *
 *  Created on: Jul 11, 2012
 *
 * Nicola Vigano', 2012, ID11 @ ESRF vigano@esrf.eu
 */

#include "internal_cell_defs.h"

const char * errorID = "C_FUN:cell_sum_copy:wrong_argument";

void mexFunction( int nlhs, mxArray * plhs[], int nrhs, const mxArray * prhs[] )
{
  if (nrhs != 2) {
    mexErrMsgIdAndTxt(errorID,
        "Not enough arguments! you need to provide two cell arrays");
  }
  if (!mxIsCell(prhs[0])) {
    mexErrMsgIdAndTxt(errorID,
        "The first argument should be a Cell array");
  }
  if (!mxIsCell(prhs[1])) {
    mexErrMsgIdAndTxt(errorID,
        "The second argument should be a Cell array");
  }
  const mwSize numElems1 = mxGetNumberOfElements(prhs[0]);
  const mwSize numElems2 = mxGetNumberOfElements(prhs[1]);

  if (numElems1 != numElems2) {
    mexErrMsgIdAndTxt(errorID,
        "The Cell arrays should have the same size");
  }

  const mxClassID firstClass = getMxClassOfCell(prhs[0]);
  if (firstClass != getMxClassOfCell(prhs[1])) {
    mexErrMsgIdAndTxt(errorID,
        "The arguments need to be Cell arrays of coherent floating point types");
  }

  plhs[0] = (mxArray *) prhs[0];


  switch (firstClass) {
    case mxDOUBLE_CLASS: {
      inner_sum<double> func;
#ifdef __SSE2__
      cell_iteration_sse<double, false>(plhs[0], prhs[1], func);
#else
      cell_iteration<double, false>(plhs[0], prhs[1], func);
#endif
      break;
    }
    case mxSINGLE_CLASS: {
      inner_sum<float> func;
#ifdef __SSE2__
      cell_iteration_sse<float, false>(plhs[0], prhs[1], func);
#else
      cell_iteration<float, false>(plhs[0], prhs[1], func);
#endif
      break;
    }
    case mxUNKNOWN_CLASS: {
      mexErrMsgIdAndTxt(errorID,
          "The argument needs to be a non empty Cell array of coherent floating point types");
    }
    default: {
      mexErrMsgIdAndTxt(errorID,
          "The argument needs to be a Cell array of floating point numbers");
    }
  }
}

