classdef GtTasksStatistics < handle
    properties
        entries = struct();
    end

    methods
        function add_task(self, name, description)
            self.entries.(name) = struct('description', description, ...
                'timestamps', [], 'timer_tic', 0);
        end

        function tic(self, name)
            self.entries.(name).timer_tic = tic();
        end

        function toc(self, name)
            self.entries.(name).timestamps = ...
                [self.entries.(name).timestamps, toc(self.entries.(name).timer_tic)];
        end
        
        function printStats(self, order)
            if (~exist('order', 'var'))
                order = 'no-order';
            end
            fields = fieldnames(self.entries);
            switch (order)
                case 'no-order'
                case 'time'
                    times = cellfun(@(x)mean(self.entries.(x).timestamps), fields);
                    [~, idx] = sort(times, 'descend');
                    fields = fields(idx);
            end

            max_descr_length = max(cellfun(@(x)length(self.entries.(x).description), fields));
            max_descr_length = max(mod(4 - mod(max_descr_length, 4), 4) + 2 + max_descr_length, 4);
            format_str = ['%' sprintf('%d', max_descr_length) 's: %10s (s) [std %f (s), %d invocations]\n'];
            format_str_alternative = ['%' sprintf('%d', max_descr_length) 's: No invocations\n'];
            for ii = 1:numel(fields)
                entry = self.entries.(fields{ii});
                if (~isempty(entry.timestamps))
                    fprintf(format_str, ...
                        entry.description, ...
                        sprintf('%f', mean(entry.timestamps)), ...
                        std(entry.timestamps), numel(entry.timestamps));
                else
                    fprintf(format_str_alternative, entry.description);
                end
            end
        end

        function res = get_mean(self, name)
            res = mean(self.entries.(name).timestamps);
        end

        function res = get_total(self, name)
            res = sum(self.entries.(name).timestamps);
        end

        function res = get_formatted_mean(self, name)
            res = datestr(self.get_mean(name) / 24 / 3600, 'HH:MM:SS.FFF');
        end

        function res = get_formatted_total(self, name)
            res = datestr(self.get_total(name) / 24 / 3600, 'HH:MM:SS.FFF');
        end
    end
end