function gtStatus(completeCheck)
% GTSTATUS  Checks the status of a dataset, show progress where possible
%           and tell a user where one might have a problem.
%     gtStatus(completeCheck)
%     -----------------------
%       to add - prompts
%              - look into most recent OAR stats to get more info
%
%     Version 002 05-10-2012 by LNervo
%       Add feedback from rec
%
%     Version 001.2 23/08/2012 by LNervo
%       Code formatting
%
%     Version 001 by AKing

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FIRST THINGS FIRST - PARAMETERS FILE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% is there a parameters file?
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
if exist('parameters.mat', 'file')
    load parameters
    fprintf('Found a parameters file...\n')
    fprintf('Dataset name is %s\n', parameters.acq.name)
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
else
    fprintf('No parameters.mat file found!  Are you in the analysis directory?\n')
    a=pwd;
    fprintf('Current directory is:  %s\n', a)
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
    return
end

problem_list{1}='List of possible problems:';
prompt=[];

if ~exist('completeCheck','var') || isempty(completeCheck)
    completeCheck = false;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% WHERE ARE WE REGARDING OAR JOBS?
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if exist('oar.log', 'file')
    fid=fopen('oar.log');
    oarlog=textscan(fid, '%s %s %d %s %s');
    fclose(fid);
    % most recent function name
    names=oarlog{2};
    lastoar_name=names{end};
    arrays=oarlog{3};
    lastoar_array=arrays(end);
    [~, status]=unix(sprintf('oarstat --array %d', lastoar_array));
    % read job numbers from this text - assume format doesn't change!
    % get exit code with gtOarGetStats
    ndx=160;
    job_status='';
    count=0;
    query{1}='exit_code'; query{2}='state';
    %this will be skipped, if status is an empty array
    while ndx<length(status)
        count=count+1;
        job=str2num(status(ndx:ndx+6));
        jobstat=gtOarGetStats(job, query);
        exit_code=jobstat{1}.exit_code;
        state=jobstat{1}.state;
        if strcmp(state, 'Running')
            job_status(count)='R';
        elseif strcmp(state, 'Terminated') && strcmp(exit_code, '0 (0,0,0)')
            job_status(count)='T';
        elseif strcmp(state, 'Terminated')
            job_status(count)='E';
        else
            disp('could read this oar job...')
        end
        ndx=ndx+81;
    end
    %status variable can be empty, concanating from oarlog
    launch_time=char(strcat(oarlog{4}(end),{' '},oarlog{5}(end)));
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
    fprintf('Last OAR job was %s \n(array %d launched at %s) \n', lastoar_name, lastoar_array, launch_time)

    % finished?
    if all(job_status=='T' | job_status=='E')
        fprintf('All these jobs have finished\n')
    end
    % errors?
    if all(job_status=='E')
        fprintf('All of these jobs show errors\n')
    elseif any(job_status=='E')
        fprintf('Some of these jobs show errors\n')
    end
    % still running?
    if all(job_status=='R')
        fprintf('All of these jobs are still running\n')
    elseif any(job_status=='R')
        fprintf('Some of these jobs are still running\n')
    end

else
    fprintf('No oar.log file found...  \n')
    fprintf('Possible OAR problem?  \n')
end
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% WHAT IMAGES ARE PRESENT?
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If we found a parameters file, how many raw images should there be?
if strcmp(parameters.acq.type, '360degree')
    totproj = 2*parameters.acq.nproj;
elseif strcmp(parameters.acq.type, '180degree')
    totproj = parameters.acq.nproj;
else
    Mexc = MException('ACQ:invalid_parameter', ...
        'Unknown type of scan. Check parameters.acq.type!');
    throw(Mexc);
end

if parameters.acq.mono_tune ~= 0
    extra_refs = ceil(totproj / (parameters.acq.refon * parameters.acq.mono_tune)) * parameters.acq.nref;
else
    extra_refs = 0;
end
if parameters.acq.interlaced_turns == 0
    filename = sprintf('%s%d0*.edf',parameters.acq.name,parameters.acq.nproj/100);
elseif parameters.acq.interlaced_turns > 0
    filename = sprintf('%s*_%d0*.edf',parameters.acq.name,parameters.acq.nproj/100);
end
if ~isempty( dir( fullfile(parameters.acq.dir,'0_rawdata','Orig', filename ) ) )
    extra_proj = length( dir( fullfile(parameters.acq.dir,'0_rawdata','Orig', filename) ) );
else
    extra_proj = 0;
end
nrefgroups=(totproj/parameters.acq.refon)+1;
totref = nrefgroups*parameters.acq.nref + extra_refs;
% how many preprocessed images do we expect?
totrefHST=(totproj/parameters.acq.refon)+1+totproj / (parameters.acq.refon * parameters.acq.mono_tune);
totabsmed=(totproj/parameters.prep.absint)+1;
totfullmed=(totproj/parameters.prep.fullint)+1;

disp('checking what images are present')

% make the first check on the full images.  If these are not all present,
% look into the other images to see what is missing:

d=dir(fullfile(parameters.acq.dir,'1_preprocessing','full', 'full*.edf'));
nfull=length(d);
fprintf('found %d full images out of %d expected\n', nfull, totproj)
if nfull~=totproj
    problem_list{end+1}='missing full images : possible gtCreateFullLive problem';
    preprocessing_ok=false;
else
    preprocessing_ok=true; 
end

% was preprocessing successful?
if completeCheck || ~preprocessing_ok

    fprintf('Checking raw, corrected and preprocessed images')

    % Orig images
    d=dir(fullfile(parameters.acq.dir,'0_rawdata','Orig', [parameters.acq.name '*.edf']));
    n_orig=length(d);
    fprintf('found %d raw images out of %d expected\n', n_orig, totproj+extra_proj)
    if n_orig<totproj
        problem_list{end+1}='missing raw images: possible gtCopyCorrectUndistortCondor problem';
    end
    d=dir(fullfile(parameters.acq.dir,'0_rawdata','Orig', 'ref*_*.edf'));
    nref_orig=length(d);
    fprintf('found %d raw references out of %d expected\n', nref_orig, totref)
    if nref_orig~=totref
        problem_list{end+1}='missing raw reference images: possible gtCopyCorrectUndistortCondor problem';
    end
    d=dir(fullfile(parameters.acq.dir,'0_rawdata','Orig', 'dark*.edf'));
    if ~isempty(d)
        fprintf('found at least one dark images\n')
    else
        fprintf('No raw dark image found\n')
        problem_list{end+1}='missing raw dark image: possible gtCopyCorrectUndistortCondor problem';
    end

    % Treated images
    d=dir(fullfile(parameters.acq.dir,'0_rawdata', parameters.acq.name, [parameters.acq.name '*.edf']));
    n_copy=length(d);
    fprintf('found %d copied images out of %d expected\n', n_copy, totproj+extra_proj)
    if n_copy<totproj
        problem_list{end+1}='missing copied images: possible gtCopyCorrectUndistortCondor problem';
    end

    d=dir(fullfile(parameters.acq.dir,'0_rawdata', parameters.acq.name, 'ref*_*.edf'));
    nref_copy=length(d);
    fprintf('found %d copied references out of %d expected\n', nref_copy, totref)
    if nref_copy~=totref
        problem_list{end+1}='missing copied reference images: possible gtCopyCorrectUndistortCondor problem';
    end

    d=dir(fullfile(parameters.acq.dir,'0_rawdata', parameters.acq.name, 'dark*.edf'));
    ndark_copy=length(d);
    if ndark_copy>0
        fprintf('found at least one copied dark images\n')
    end

    % was copying successful?
    if n_copy==totproj && nref_copy==totref && ndark_copy>0
        copy_ok=true;
    end

    % Preprocessed images
    disp('checking for other preprocessed images...')
    d=dir(fullfile(parameters.acq.dir,'0_rawdata', parameters.acq.name, 'refHST*.edf'));
    nrefHST=length(d);
    fprintf('found %d refHST images out of %d expected\n', nrefHST, totrefHST)
    if nrefHST~=totrefHST
        problem_list{end+1}='missing refHST images : possible gtSequenceMedianRefs problem';
    end

    d=dir(fullfile(parameters.acq.dir,'1_preprocessing/abs', 'abs*.edf'));
    nabs=length(d);
    if parameters.acq.interlaced_turns > 0
        d2=dir(fullfile(parameters.acq.dir,'1_preprocessing/abs', 'abs_renumbered*.edf'));
        disp('abs_renumbered have already been created')
    else
        d2 = 0;
    end
    fprintf('found %d abs images out of %d expected\n', nabs, totproj+length(d2))
    if nabs~=totproj+length(d2)
        problem_list{end+1}='missing abs images : possible gtCreateAbsLive problem';
    end

    d=dir(fullfile(parameters.acq.dir,'1_preprocessing/abs', 'med*.edf'));
    nabsmed=length(d);
    fprintf('found %d abs median images out of %d expected\n', nabsmed, totabsmed)
    if nabsmed~=totabsmed
        problem_list{end+1}='missing abs median images : possible gtAbsMedianLive problem';
    end

    d=dir(fullfile(parameters.acq.dir,'1_preprocessing/full', 'med*.edf'));
    nfullmed=length(d);
    fprintf('found %d full median images out of %d expected\n', nfullmed, totfullmed)
    if nfullmed~=totfullmed
        problem_list{end+1}='missing full median images : possible gtMovingMedianLive problem';
    end

end % if full images present
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SEGMENTATION STATUS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Connecting to database to check segmentation...')
gtDBConnect();

if strcmp(parameters.seg.method, 'doublethr')

    fprintf('Segmentation method: Double threshold \n')

    % seed segmentation status
    cmd=sprintf('select count(*) from %sfullmedianvals', parameters.acq.name);
    n_fmv=mym(cmd);
    cmd=sprintf('select count(*) from %sfullmedianvals where !isnull(val)', ...
        parameters.acq.name);
    n_fmv_finished=mym(cmd);
    fprintf('Seed segmentation completed %d images out of %d\n', n_fmv_finished, n_fmv)
    if n_fmv~=n_fmv_finished
        problem_list{end+1}='gtSeedSegmentation_doublethr has not finished';
    end

    % blob segmentation progress

    cmd=sprintf('select count(*) from %sseeds', parameters.acq.name);
    tot_seeds=mym(cmd);
    cmd=sprintf('select count(*) from %sseeds_tmp', parameters.acq.name);
    done_seeds=mym(cmd);
    if done_seeds~=tot_seeds
        problem_list{end+1}='gtSegmentDiffractionBlobs_doublethr has not finished';
    end
    cmd=sprintf('select count(*) from %sdifblob', parameters.acq.name);
    n_blobs=mym(cmd);
    fprintf('Segmentation has treated %d out of %d seeds\n',done_seeds, tot_seeds)
    fprintf('Segmentation has found %d blobs\n', n_blobs')

    % was segmentation successful?
    if done_seeds==tot_seeds && n_blobs>1
        blobs_ok=true;
    end

elseif strcmp(parameters.seg.method, 'doublethr_new')
  
    fprintf('Segmentation method: Double threshold NEW GUI\n')

    % segmentation status
    cmd=sprintf('select count(*) from %sfullmedianvals', parameters.acq.name);
    n_fmv=mym(cmd);
    cmd=sprintf('select count(*) from %sfullmedianvals where !isnull(val)', ...
        parameters.acq.name);
    n_fmv_finished=mym(cmd);
    fprintf('Segmentation completed %d images out of %d\n', n_fmv_finished, n_fmv)
    if n_fmv~=n_fmv_finished
        problem_list{end+1}='gtSegmentationDoubleThreshold has not finished';
    end

    % blob segmentation progress
    cmd=sprintf('select count(*) from %sdifblob', parameters.acq.name);
    n_blobs=mym(cmd);
    fprintf('Segmentation has found %d blobs\n', n_blobs')

    % was segmentation successful?
    if n_blobs>1
        blobs_ok=true;
    end
    
elseif strcmp(parameters.seg.method, 'singlethr')

    fprintf('Segmentation method: Single threshold \n')

    n_blobs=sprintf('select count(*) from %sdifblob', parameters.acq.name);
    fprintf('Segmentation has found %d blobs\n',n_blobs)

    % was segmentation successful?
    if  nblobs>1
        blobs_ok=true;
    end
else
    fprintf('Segmentation method not recognised! \n')
end

% spot segmentation progress
cmd=sprintf('select count(*) from %sdifspot', parameters.acq.name);
n_spots=mym(cmd);
fprintf('Database has %d difspots from %d blobs\n',n_spots, n_blobs)
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PAIRMATCHING STATUS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Checking pair matching...')
for ii=length(parameters.cryst)
cmd=sprintf('select count(*) from %s where  phasetype=%d', parameters.acq.pair_tablename, ii);
n_pairs(ii)=mym(cmd);
if n_pairs(ii)==0
    pair_percentage=0;
else
    pair_percentage=100*(2*n_pairs(ii))/n_spots;
end
fprintf('Database has %d spot pairs for phase %d from %d difspots (%0.1f%% matching) \n'...
        ,n_pairs(ii), ii, n_spots, pair_percentage )
end
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INDEXING STATUS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% is there an input file?
for ii=length(parameters.cryst)
    d=dir(sprintf('4_grains/phase_%02d/index_input.mat', ii));
    if ~isempty(d)
        fprintf('Indexing input file found for phase %02d:\n', ii)
        inp=load(sprintf('4_grains/phase_%02d/index_input.mat', ii));
        fprintf('This file was created %s \n', d.date)
        n_pairs_inp(ii)=length(inp.tot.pairid);
        if n_pairs_inp(ii)~=n_pairs(ii)
            fprintf('!!! Strong warning !!! \n')
            fprintf('Number of pairs in the indexing input file does not match the spotpair table\n')
            fprintf('If you have update the pair matching, un-check "use input file" in gtSetupIndexing\n')
        else
            fprintf('indexing input looks consistant with the spot pairs table\n')
        end
    else
        fprintf('No indexing input file for phase %d \n', ii)
    end

    % is there an output file?
        d2=dir(sprintf('4_grains/phase_%02d/index.mat', ii));
        if ~isempty(d2)
            fprintf('Indexing results found for phase %02d:\n', ii)
            fprintf('Latest output file date: %s\n', d2.date)
            a=load(sprintf('4_grains/phase_%02d/index.mat', ii));
            n_grains(ii)=length(a.grain);
            fprintf('Latest output contains %d indexed grains\n', n_grains(ii))
        else
            fprintf('No indexing output found for phase %02d\n', ii)
        end

        if d.datenum>d2.datenum
            fprintf('!!! Strong warning !!! \n')
            fprintf('Input file is newer than the output file! Indexing has started but not been finished\n')
        end
end
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FORWARD SIMULATION STATUS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for ii=1:length(parameters.cryst)

    fprintf('checking grain .mat files for phase %d\n', ii)
    d=dir(sprintf('4_grains/phase_%02d/grain_*.mat', ii));
    n_grains_mat(ii)=length(d);
    if n_grains(ii)==n_grains_mat
        fprintf('Correct number (%d) of grain_%%04d.mat files found\n', n_grains_mat(ii));
    elseif n_grains_mat==0
        fprintf('No grain_%%04d.mat file found\n')
    else
        fprintf('Some grain_%%04d.mat files missing!\n')
    end
    
    sample=[];
    load('4_grains/sample.mat');
    
    grains_conflicts = [];
    load('4_grains/grains_conflicts.mat');
    phase = sample.phases{ii};
    
    check=false(4,length(d));
    for jj=1:length(d)
        a = load(sprintf('4_grains/phase_%02d/grain_%04d.mat', ii, jj));
        if all( a.center == phase.center(jj,:) )
            check(1,jj) = true;
        end
        if a.completeness == phase.completeness(jj) 
            check(2,jj) = true;
        end
        if all(a.selected == phase.grains{jj}.selectedDiffspots)
            check(3,jj) = true;
        end
        if all(a.difspotID' == grains_conflicts{ii}.getDifspotID(jj))
            check(4,jj) = true;
        end
    end

end

check = inputwdefault('use gtFsimCheckMissingGrains to check forward sim output? [y/n]', 'n');
if strcmpi(check, 'y')
    for ii=length(parameters.cryst)
        fprintf('Check forward simulation for phase %02d:\n', ii)
        list=gtFsimCheckMissingGrains(ii);
        if isempty(list.ind) && isempty(list.old)
            fprintf('Forward simulation seems ok\n')
        elseif ~isempty(list.ind)
            fprintf('Forward simulation failed for %d grains:\n', length(list.ind))
            fprintf('grain_####.mat does not exist for grains:\n')
            disp(list.ind)
        elseif ~isempty(list.old)
            fprintf('Forward simulation has to be checked for %d grains:\n', length(list.old))
            fprintf('grain_####.mat is old for grains:\n')
            disp(list.old)
        end
        if ~isempty(list.checkFsim)
            fprintf('Wrong grainid for %d grains from Forward Simulation:\n', length(list.checkFsim))
            fprintf('grain_####.mat has wrong grainid for grains:\n')
            disp(list.checkFsim)
        end
        if ~isempty(list.checkIndexter)
            fprintf('Wrong grainid for %d grains from Indexter:\n', length(list.checkIndexter))
            fprintf('index.mat:grain has wrong grainid for grains:\n')
            disp(list.checkIndexter)
        end
    end % end for phaseid
end
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RECONSTRUCTION STATUS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for ii=length(parameters.cryst)
    title = sprintf('Check grain reconstructions for phase %02d: ', ii);
    if exist(sprintf('4_grains/phase_%02d/index.mat', ii), 'file')
        a=load(sprintf('4_grains/phase_%02d/index.mat', ii));
        gauge = GtGauge(length(a.grain), title);
        check=zeros(length(a.grain), 4);
        warning('OFF') % hide warning messages
        for jj=1:length(a.grain)
            gauge.incrementAndDisplay();
            b=load(sprintf('4_grains/phase_%02d/grain_%04d.mat', ii, jj), 'vol', 'seg');
            if isfield(b, 'vol') && ~isempty(b.vol)
                check(jj, 1)=1;
            else
                check(jj, 3)=jj;
            end
            if isfield(b, 'seg') && ~isempty(b.seg)
                check(jj, 2)=1;
            else
                check(jj, 4)=jj;
            end
        end
        gauge.delete();
        fprintf('Reconstructed %d grains out of %d\n', sum(check(:,1)), length(a.grain))
        fprintf('Segmented %d grains out of %d\n', sum(check(:,2)), length(a.grain))
        if any(check(:,3))
            disp('  Missing grain_####.mat:vol for ID(s):')
            disp(check(:,3))
        end
        if any(check(:,4))
            disp('  Missing grain_####.mat:seg for ID(s):')
            disp(check(:,4))
        end
        % dates on these files
        d=dir('4_grains/phase_01/grain*.mat');
        filedates=zeros(1, length(d));
        for jj=1:length(d)
            filedates(jj)=d(jj).datenum;
        end
        [~, min_ndx]=min(filedates);
        [~, max_ndx]=max(filedates);
        fprintf('Earliest grain.mat file dates from %s\n', d(min_ndx).date)
        fprintf('Latest grain.mat file dates from %s\n', d(max_ndx).date)
    else
        fprintf('\nNo indexter output found\n')
    end

    warning('ON') % hide warning messages
end
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ASSEMBLED VOLUMES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('Check reconstructed/assembled volumes\n')

d=dir('5_reconstruction/volume_absorption.mat');
if length(d)==1
    fprintf('Found absorption reconstruction: volume_absorption.mat\n')
    fprintf('File date is %s\n', d.date)
else
    fprintf('No absorption reconstruction found\n')
end
d=dir('5_reconstruction/volume_mask.mat');
if length(d)==1
    fprintf('Found absorption mask: volume_mask.mat\n')
    fprintf('File date is %s\n', d.date)
else
    fprintf('No absorption mask found\n')
end

for ii=length(parameters.cryst)
    d=dir(sprintf('5_reconstruction/phase_%02d_vol.mat', ii));
    if length(d)==1
        fprintf('Found DCT reconstruction for phase %d: phase_%02d_vol.mat\n', ii, ii)
        fprintf('File date is %s\n', d.date)
    else
        fprintf('No DCT reconstruction found for phase %d\n', ii)
    end
end

d=dir('5_reconstruction/volume.mat');
if length(d)==1
    fprintf('Found DCT reconstruction: volume.mat\n')
    fprintf('File date is %s\n', d.date)
else
    fprintf('No DCT reconstruction found\n')
end
d=dir('5_reconstruction/volume_dilated.mat');
if length(d)==1
    fprintf('Found postprocessed DCT reconstruction: volume_dilated.mat\n')
    fprintf('File date is %s\n', d.date)
else
    fprintf('No postprocessed DCT reconstruction found\n')
end
disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%')
disp(' ')
disp(' ')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Show problems
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if length(problem_list) > 1
    for ii=1:length(problem_list)
        fprintf('%s\n', problem_list{ii})
    end
end

end % end of gtStatus
