#!/usr/bin/env python

import vtk
import sys

# Show vtk version
print "Using vtk version", vtk.vtkVersion.GetVTKVersion()

# Parameters
initAngle = -45.

# Set input filename
try :
    meshFile = sys.argv[1]
except :
    print 'Missing input file'

# Reader
reader = vtk.vtkDataSetReader()
reader.SetFileName(meshFile)
reader.ReadAllScalarsOn() 
reader.ReadAllColorScalarsOn() 
reader.Update()

# Polydata
if reader.IsFilePolyData():
    polydata = reader.GetOutput()
else:
    raise RuntimeError('Input mesh file does not contain a mesh (vtkPolyData)!')

# Print mesh information
nPoints = polydata.GetNumberOfPoints()
nLines  = polydata.GetNumberOfLines()
nCells  = polydata.GetNumberOfCells()
print "This file contains:"
print "  %9d points" % nPoints
print "  %9d lines"  % nLines
print "  %9d cells"  % nCells

# Cell data fields
cellData = polydata.GetCellData()
nFields = cellData.GetNumberOfArrays()
print 'This file contains %d cell data fields' % nFields
for i in range(nFields):
    field     = cellData.GetArray(i)
    name      = field.GetName()
    nComp     = field.GetNumberOfComponents()
    dataType  = field.GetDataTypeAsString()
    dataRange = field.GetRange()
    print '  % 3d %-25s (%d x %-15s) [ %g , %g ]' % (i+1, name, nComp, \
            dataType, dataRange[0], dataRange[1])
if len(sys.argv) > 2:
    iField = int(sys.argv[2]) - 1
elif nFields > 1:
    iField = -1 
    while iField < 0 or iField >= nFields:
        print 'Which field do you want to display (enter index)?'
        a = raw_input()
        iField = int(a) - 1
        print "You have chosen field %s (index %d)." %(a, iField)
else:
    iField = 0
displayDataName = cellData.GetArrayName(iField)
print 'Displaying field number %d named "%s"' % (iField+1, displayDataName)
displayData = cellData.GetArray(iField)

# Mapper
mapper = vtk.vtkPolyDataMapper()
if vtk.vtkVersion.GetVTKMajorVersion() <= 5:
    mapper.SetInput(polydata)
else:
    mapper.SetInputData(polydata)

mapper.SetInputArrayToProcess(iField, polydata.GetInformation())
mapper.SelectColorArray(iField)
mapper.SetScalarModeToUseCellFieldData()

if displayData.GetNumberOfComponents() >= 3:
    print "Using colors from RGB color field"
    mapper.SetColorModeToDefault()
elif displayData.GetNumberOfComponents() == 1:
    print "Using colors from lookup table"
    mapper.SetScalarRange(displayData.GetRange())
    mapper.SetLookupTable(displayData.GetLookupTable())
else:
    print '!' 

# Actor
actor = vtk.vtkActor()
actor.SetMapper(mapper)

# Renderer
renderer = vtk.vtkRenderer()

# Render window
renderWindow = vtk.vtkRenderWindow()
renderWindow.AddRenderer(renderer)
renderWindow.FullScreenOn()

# Window interactor
renderWindowInteractor = vtk.vtkRenderWindowInteractor()
renderWindowInteractor.SetRenderWindow(renderWindow)
renderer.AddActor(actor)
renderWindow.Render()

# Axes
axes = vtk.vtkAxesActor()
#axes = vtk.vtkAnnotatedCubeActor()
#axes.SetTotalLength(50,50,50)
#renderer.AddActor(axes)

# Axes widget
widget = vtk.vtkOrientationMarkerWidget()
widget.SetOutlineColor(0.9300, 0.5700, 0.1300)
widget.SetOrientationMarker(axes)
widget.SetInteractor(renderWindowInteractor)
widget.SetViewport(0.0, 0.0, 0.3, 0.3)
widget.SetEnabled(1)
widget.InteractiveOff()
#widget->InteractiveOn()

# Camera
camera = renderer.GetActiveCamera()
camera.Elevation(initAngle)
camera.SetViewUp(0, 0, 1)
renderWindow.Render()

# Trackball
style = vtk.vtkInteractorStyleTrackballCamera()
renderWindowInteractor.SetInteractorStyle(style)

renderWindowInteractor.Start()

# Close vtk file
reader.CloseVTKFile()
